Standard Generated Output File

# Codeaudit overview report

Codeaudit overview scan of the directory: src/gentrie

## Summary

Number_Of_Files | Number_Of_Lines | AST_Nodes | Core Modules | External Modules | Functions | Classes | Comment_Lines | Median_Complexity | Maximum_Complexity
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
7 | 1303 | 311 | 6 | 5 | 35 | 9 | 824 | 9.1 | 48

Based on the maximum found complexity in a source file: Security concern rate is HIGH

Based on the total Lines of Code (LoC) : Security concern rate is LOW

Click to see all discovered modules.

### Core_modules

- collections
- collections.abc
- copy
- textwrap
- types
- typing

### Imported_modules

- exceptions
- nodes
- protocols
- trie
- validation

The command "codeaudit modulescan" can be used to check if vulnerabilities are reported in an external module.

## Detailed overview per source file

Click to see the report details.

FileName | FilePath | Number_Of_Lines | AST_Nodes | Std-Modules | External-Modules | Functions | Classes | Comment_Lines | Complexity_Score | warnings
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
protocols.py | /Users/snowhare/git/python-gen-tries/src/gentrie/protocols.py | 99 | 17 | 2 | 0 | 4 | 2 | 75 | 1 | 0
__init__.py | /Users/snowhare/git/python-gen-tries/src/gentrie/__init__.py | 234 | 7 | 1 | 4 | 0 | 0 | 197 | 1 | 0
types.py | /Users/snowhare/git/python-gen-tries/src/gentrie/types.py | 52 | 34 | 1 | 1 | 5 | 2 | 14 | 3 | 0
exceptions.py | /Users/snowhare/git/python-gen-tries/src/gentrie/exceptions.py | 21 | 7 | 0 | 0 | 0 | 3 | 12 | 1 | 0
nodes.py | /Users/snowhare/git/python-gen-tries/src/gentrie/nodes.py | 89 | 38 | 4 | 2 | 3 | 1 | 34 | 7 | 0
trie.py | /Users/snowhare/git/python-gen-tries/src/gentrie/trie.py | 753 | 196 | 5 | 4 | 20 | 1 | 458 | 48 | 0
validation.py | /Users/snowhare/git/python-gen-tries/src/gentrie/validation.py | 55 | 12 | 1 | 1 | 3 | 0 | 34 | 3 | 0

## Visual Overview